@@ -28,13 +28,13 @@
 
 #include <iostream>
 
+#include "checkerboardimageprovider.h"
 #include "filemenu.h"
 #include "filesystemtracker.h"
 #include "imagestorage.h"
 #include "kokoconfig.h"
 #include "openfilemodel.h"
 #include "processor.h"
-#include "vectorimage.h"
 #include "version.h"
 
 #ifndef Q_OS_ANDROID
@@ -80,7 +80,11 @@ int main(int argc, char **argv)
 
     aboutData.addAuthor(xi18nc("@info:credit", "Nicolas Fella"), xi18nc("@info:credit", "Developer"), "nicolas.fella@gmx.de");
 
-    aboutData.addAuthor(xi18nc("@info:credit", "Carl Schwan"), xi18nc("@info:credit", "Developer"), "carl@carlschwan.eu");
+    aboutData.addAuthor(xi18nc("@info:credit", "Carl Schwan"),
+                        xi18nc("@info:credit", "Developer"),
+                        "carl@carlschwan.eu",
+                        QStringLiteral("https://carlschwan.eu"),
+                        QUrl(QStringLiteral("https://carlschwan.eu/avatar.png")));
 
     aboutData.addAuthor(xi18nc("@info:credit", "Mikel Johnson"), xi18nc("@info:credit", "Developer"), "mikel5764@gmail.com");
 
@@ -110,9 +114,9 @@ int main(int argc, char **argv)
 
     const QUrl currentDirPath = QUrl::fromLocalFile(QDir::currentPath().append('/'));
 
-    QStringList directoryUrls;
+    QList<QUrl> directoryUrls;
     for (const auto &path : parser.positionalArguments()) {
-        directoryUrls << currentDirPath.resolved(path).toString();
+        directoryUrls << QUrl::fromUserInput(path, QDir::currentPath(), QUrl::AssumeLocalFile);
     }
 
 #ifdef Q_OS_ANDROID
@@ -120,7 +124,6 @@ int main(int argc, char **argv)
 #endif
 
     FileSystemTracker tracker;
-    tracker.setFolder(locations.first());
     tracker.moveToThread(&trackerThread);
 
     Koko::Processor processor;
@@ -131,26 +134,34 @@ int main(int argc, char **argv)
     QObject::connect(&trackerThread, &QThread::started, &tracker, &FileSystemTracker::setupDb);
 
     trackerThread.start();
-    tracker.setSubFolder(tracker.folder());
+
+    const QString imageDirLocation = locations.first();
+    QMetaObject::invokeMethod(&tracker, [&tracker, imageDirLocation]() {
+        tracker.setFolder(imageDirLocation);
+        tracker.setSubFolder(tracker.folder());
+    });
 
     QQmlApplicationEngine engine;
     KLocalization::setupLocalizedContext(&engine);
+    engine.addImageProvider("checkerboard", new CheckerboardImageProvider);
+
+    const auto openFileModel = engine.singletonInstance<OpenFileModel *>("org.kde.koko", "OpenFileModel");
+    openFileModel->updateOpenItems(directoryUrls);
 
-    OpenFileModel openFileModel(directoryUrls);
     QObject::connect(&service,
                      &KDBusService::activateRequested,
-                     &openFileModel,
-                     [&openFileModel, &parser, &engine](const QStringList &arguments, const QString &workingDirectory) {
+                     openFileModel,
+                     [openFileModel, &parser, &engine](const QStringList &arguments, const QString &workingDirectory) {
                          QUrl currentDirPath = QUrl::fromLocalFile(workingDirectory);
 
                          parser.parse(arguments);
 
-                         QStringList directoryUrls;
+                         QList<QUrl> directoryUrls;
                          for (const auto &path : parser.positionalArguments()) {
-                             directoryUrls << currentDirPath.resolved(path).toString();
+                             directoryUrls << QUrl::fromUserInput(path, QDir::currentPath(), QUrl::AssumeLocalFile);
                          }
 
-                         openFileModel.updateOpenFiles(directoryUrls);
+                         openFileModel->updateOpenItems(directoryUrls);
 
                          const auto rootObjects = engine.rootObjects();
                          for (auto obj : rootObjects) {
@@ -163,8 +174,6 @@ int main(int argc, char **argv)
                          }
                      });
 
-    qmlRegisterSingletonInstance("org.kde.koko.private", 1, 0, "OpenFileModel", &openFileModel);
-    qmlRegisterType<VectorImage>("org.kde.koko.image", 1, 0, "VectorImage");
     qmlRegisterType<FileMenu>("org.kde.koko.private", 1, 0, "FileMenu");
 
     engine.rootContext()->setContextProperty("kokoProcessor", &processor);
@@ -175,5 +184,6 @@ int main(int argc, char **argv)
 
     int rt = app.exec();
     trackerThread.quit();
+    trackerThread.wait();
     return rt;
 }
